// =============  MOVE-A-BOX FUNCTIONS ==================

/* Copyright 2013. Daniel Hellerstein (danielh@crosslink.net)

This file is part of carCosts2.

    carCosts2 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    carCosts2 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with carCosts2.  If not, see <http://www.gnu.org/licenses/>.
*/

// for creating a moveable/resizeable DIV (or other container)
// The following initializations are required
//
//  1) Include this library (i.e.;   <script type="text/javascript" src="moveBox.js"></script>
//
//  2) In a <script type="text/javascript">, declare several globals, using:
//        var _boxid, _firstMouseX,_firstMouseY,_nowMouseX,_nowMouseY,_startingAtX,_startingAtY ;
//        var  _firstRMouseX,_firstRMouseY,_nowRMouseX,_nowRMouseY,_startingRAtX,_startingRAtY, _startingAtW,_startingAtH ;
//  Note the use of   _boxid, a global variable, to identify the box (to be moved). Thus, only one moveable/resizable box can be created
//
//  3) Create a DIV (or other element) that will be the moveable box.
//     It should have a style (not a class) listing position (see below), and height and width. If you don't include these attributes,
//     defaults will be used, and  moving & resizing might be a bit hurky-jerky
//     For example:
//            <div id="moveme" style="position:relative;left:10px;top:10px;width:50%;height:100px">  ... </div>
//      Note that the left, top, width, and height can be in pixels (px) or % of current screen size (%)
//
//  3b)  In this DIV, be sure to specify two "buttons": that will be used for moving and resizing
//        For example:
//           <input type="button" id="moveButton" title="click and hold to move this help box" value="o" style="font-size:70%"  >
//           <input type="button" id="resizeButton" title="click and hold to resize"  style="font-size:70%;padding:1px" value="&laquo;&raquo;"  >
//
//  4) In an function (say, that is called by onLoad) initialize some globals: a pointer to moveable box, and events for the buttons
//     Example:
//        If "moveme" is the id of the moveable box,
//         "moveButton" the id of  the button to be used for moving the box, and
//         "resizeButton" the id of the button used to resize the box
//     then include the following
//          _boxid=document.getElementById('moveme');
//           document.getElementById('moveButton').onmousedown=_moveDoStartMove ;
//          document.getElementById('resizeButton').onmousedown=_moveDoStartResize ;
//
//  Moving and resizing are done by clicking on the button, holding the button down, and moving it.

function _moveDoStartMove(e) {

  var apos,foo;

  foo=_moveGetMouseXY(e) ;
  _firstMouseX=foo[0];_firstMouseY=foo[1] ;
  _nowMouseX=foo[0];_nowMouseY=foo[1] ;

   _startingAtX=(_boxid.style.left) ;
   _startingAtY=(_boxid.style.top) ;

    if (_startingAtX.indexOf('%')>-1) {                    // % (not px)
          _startingAtX=parseInt(parseInt(_startingAtX)*window.innerWidth/100) ;
    }   else {
        if (_startingAtX=='') _startingAtX=_firstMouseX ;
       _startingAtX=parseInt(_startingAtX);
    }
    if (_startingAtY.indexOf('%')>-1) {
          _startingAtY=parseInt(parseInt(_startingAtY)*window.innerHeight/100) ;
    }   else {
        if (_startingAtY=='') _startingAtX=_firstMouseY ;
        _startingAtY=parseInt(_startingAtY);
    }
  if (!e) var e = window.event;
  if (e.target) targ = e.target;
  else if (e.srcElement) targ = e.srcElement;
  if (targ.nodeType == 3) targ = targ.parentNode;  // defeat Safari bug


  apos=(_boxid.style.position);
  if (apos=='') {
      _boxid.style.position='relative';
      _boxid.style.left=_firstMouseX ;
      _boxid.style.top=_firstMouseY ;
  }

    document.onmouseup = _moveGetMouseXYatEndMove;       // on mouseUp, move ends!
    document.onmousemove = _moveGetMouseXYMove;       // on mousemove, move !

  return 0;
}



//=================================
// read current mouse position
function _moveGetMouseXY(e,i1) {
var tempX,tempY;

var iie = document.all?true:false;

if (iie) { // grab the x-y pos.s if browser is IE
tempX = event.clientX + document.body.scrollLeft;
tempY = event.clientY + document.body.scrollTop;
}
else {  // grab the x-y pos.s if browser is NS

tempX = e.pageX;
tempY = e.pageY;
}
if (tempX < 0){tempX = 0;}
if (tempY < 0){tempY = 0;}

return [tempX,tempY];
}



//=================================
// resizes or moves box after a mouse move (_boxid is global)
function _moveGetMouseXYMove(e) {
 var t1,t2,dx,dy;
 if (!e) var e = window.event;

 var foo=_moveGetMouseXY(e);
 if (Math.abs(foo[0]-_nowMouseX)<3 && Math.abs(foo[1]-_nowMouseY)<3) return 0 ; // small move, ignore

 _nowMouseX=foo[0]; _nowMouseY=foo[1] ;

    dx=_nowMouseX-_firstMouseX ;
    dy=_nowMouseY-_firstMouseY ;        // else, move it by dx and dy where it was a click
    t1=(_startingAtX +dx);
       t1=t1+'px' ;
      _boxid.style.left=t1 ;
    t2=(_startingAtY+dy);
       t2=t2+'px' ;
      _boxid.style.top=t2 ;


return 0;
}

//=================================
// on mouse up, end move or resize (so release the mouseup and mousemove events from the document
// if I was clever, I would reestablish a prior mouseup and mousemove (that may have beem overwritten by startMove...
function _moveGetMouseXYatEndMove(e) {

  if (!e) var e = window.event;
   if (e.target) targ = e.target;
   else if (e.srcElement) targ = e.srcElement;
   if (targ.nodeType == 3) targ = targ.parentNode;  // defeat Safari bug

 document.onmouseup = 0 ;
 document.onmousemove= 0 ;
return 0;
}

// ============= END OF MOVE-A-BOX FUNCTIONS ==================

// resize versions of move
//==============================
// resize button
function _moveDoStartResize(e) {

  var apos,foo;

  foo=_moveGetMouseXY(e) ;
  _firstRMouseX=foo[0];_firstRMouseY=foo[1] ;
  _nowRMouseX=foo[0];_nowRMouseY=foo[1] ;

   _startingRAtX=(_boxid.style.left) ;
   _startingRAtY=(_boxid.style.top) ;

    if (_startingRAtX.indexOf('%')>-1) {                    // % (not px)
          _startingRAtX=parseInt(parseInt(_startingRAtX)*window.innerWidth/100) ;
    }   else {
        if (_startingRAtX=='') _startingRAtX=_firstRMouseX ;
       _startingRAtX=parseInt(_startingRAtX);
    }
    if (_startingRAtY.indexOf('%')>-1) {
          _startingRAtY=parseInt(parseInt(_startingRAtY)*window.innerHeight/100) ;
    }   else {
        if (_startingRAtY=='') _startingRAtX=_firstRMouseY ;
        _startingRAtY=parseInt(_startingRAtY);
    }

   _startingAtH=(_boxid.style.height) ;
         if (_startingAtH=='')_startingAtH='15%' ; // an arbitrary value
   _startingAtW=(_boxid.style.width) ;
         if (_startingAtW=='')_startingAtW='55%' ; // an arbitrary value

    if (_startingAtH.indexOf('%')>-1) {                    // % (not px)
          _startingAtH=parseInt(parseInt(_startingAtH)*window.innerHeight/100) ;
    }   else {
       _startingAtH=parseInt(_startingAtH);
    }
    if (_startingAtW.indexOf('%')>-1) {
          _startingAtW=parseInt(parseInt(_startingAtW)*window.innerWidth/100) ;
    }   else {
        _startingAtW=parseInt(_startingAtW);
    }


  if (!e) var e = window.event;
  if (e.target) targ = e.target;
  else if (e.srcElement) targ = e.srcElement;
  if (targ.nodeType == 3) targ = targ.parentNode;  // defeat Safari bug


  apos=(_boxid.style.position);
  if (apos=='') {
      _boxid.style.position='relative';
      _boxid.style.left=_firstRMouseX ;
      _boxid.style.top=_firstRMouseY ;
  }

    document.onmouseup = _moveGetMouseXYatEndResize;       // on mouseUp, move ends!
    document.onmousemove = _moveGetMouseXYResize;       // on mousemove, move !

  return 0;
}



//=================================
// resizes or moves box after a mouse move (_boxid is global)
function _moveGetMouseXYResize(e) {
 var t1,t2,dx,dy;
 if (!e) var e = window.event;

 var foo=_moveGetMouseXY(e);
 if (Math.abs(foo[0]-_nowRMouseX)<8 && Math.abs(foo[1]-_nowRMouseY)<8) return 0 ; // small move, ignore

 _nowRMouseX=foo[0]; _nowRMouseY=foo[1] ;

    dx=parseInt(_nowRMouseX)-parseInt(_firstRMouseX) ;
    dy=parseInt(_nowRMouseY)-parseInt(_firstRMouseY) ;        // else, move it by dx and dy where it was a click

    t2=parseInt(_startingRAtY)+dy;    // move up (-dy moves up).But don't move x location of upper left corrner (ULC)
       t2=t2+'px' ;
      _boxid.style.top=t2 ;

    endHeight=parseInt(_startingAtH)-dy;
    endWidth=parseInt(_startingAtW)+dx;
    _boxid.style.height=endHeight+'px' ;
    _boxid.style.width=endWidth+'px' ;



return 0;
}

//=================================
// on mouse up, end move or resize (so release the mouseup and mousemove events from the document
// if I was clever, I would reestablish a prior mouseup and mousemove (that may have beem overwritten by startMove...
function _moveGetMouseXYatEndResize(e) {
 var t1,t2,endHeight,endWidth,dx,dy,oldw,oldh;
  if (!e) var e = window.event;
   if (e.target) targ = e.target;
   else if (e.srcElement) targ = e.srcElement;
   if (targ.nodeType == 3) targ = targ.parentNode;  // defeat Safari bug

 document.onmouseup = 0 ;
 document.onmousemove= 0 ;
return 0;
}


